#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>


#define maxn (64*1024)


int* tree[maxn], *pattern[maxn], ntree, npattern;

int alloc_buf[maxn*8];
int _alloc_pos;

int * my_alloc(int sz)
{ 
   int *rv =  &alloc_buf[_alloc_pos];
   _alloc_pos += sz / sizeof(int); 
   assert(_alloc_pos < maxn*8); return rv; 
}

void init(void)
{
    int i, j, nfii;
    

    scanf ("%d", &npattern);

    for (i = 1; i <= npattern; i++) {
        scanf ("%d", &nfii);
        pattern[i] = (int*) my_alloc(sizeof(int)*(nfii + 1));
        pattern[i][0] = nfii;
        for (j = 1; j <= nfii; j++)
            scanf ("%d", &pattern[i][j]);
    }

    scanf ("%d", &ntree);

    for (i = 1; i <= ntree; i++) {
        scanf ("%d", &nfii);
        tree[i] = (int*) my_alloc(sizeof(int)*(nfii + 1));
        tree[i][0] = nfii;
        for (j = 1; j <= nfii; j++)
            scanf ("%d", &tree[i][j]);
    }


}

char s[maxn*4];
int node_start[maxn];
int pattern_start, N;
int mark[maxn], countS[maxn*4];

void walk (int ** tree, int node, int is_tree)
{
    int i;
    if (mark[node] == 0) {
       mark[node] = 1;
       if (is_tree)
          node_start[node] = N;
       s[N++] = 'S';
    }
    for (i = 1; i <= tree[node][0]; i++) {
        s[N++] = 'D';
        walk(tree, tree[node][i], is_tree);
        s[N++] = 'U';
    }
}


void build_string (void)
{
    int i;

    walk (tree, 1, 1);
    s[N++] = 0;
    pattern_start = N;
    memset (mark, 0, sizeof(mark));
    walk (pattern, 1, 0);

    for (i = 0; i + pattern_start < N; i++) {
        countS[i] = i > 0 ? countS[i - 1] : 0;
        if (s[pattern_start + i] == 'S')
           countS[i] ++;
    }
}

/* suffix array stuff */


int count[maxn*4], perm[maxn*4], pos[maxn*4], bh[maxn*4], bucket[maxn*4];

void sarray(void)
{
    int i, h, e, d, cbucket, go_on;

    memset (count, 0, sizeof(count));

    for (i = 0; i < N; i++)
        count[s[i]] ++;
    for (i = 1; i < 255; i++)
        count[i] += count[i - 1];
    for (i = N - 1; i >= 0; i--)
        pos[-- count[s[i]]] = i;

    bh[0] = 1;
    for (i = 0; i < N; i++) {
        bh[i] = i == 0 || s[pos[i]] != s[pos[i - 1]];
        perm[pos[i]] = i;
    }

    for (h = 1, go_on = 1; h <= N && go_on; h *= 2) {
        for (i = 0; i < N; i++) {
            if (bh[i]) {
               cbucket = i;
               count[cbucket] = 0;
            }
            bucket[pos[i]] = cbucket;
        }

        d = N - h;
        e = bucket[d];

        perm[d] = e + count[e];
        count[e] ++;

        for (i = 0; i < N; i++) {
            d = pos[i] - h;

            if (d < 0) continue;

            e = bucket[d];
            perm[d] = e + count[e];
            count[e] ++;
        }

        for (i = 0; i < N; i++)
            pos[perm[i]] = i;

        go_on = 0;

        for (i = 1; i < N; i++) {
            bh[i] = bh[i] || (pos[i] + h >= N || pos[i - 1] + h >= N)
                          || bucket[pos[i] + h] != bucket[pos[i - 1] + h];
            if (! bh[i])
               go_on = 1;
        }
    }
}

/* longest common prefix */

int lcp[maxn*4];

void compute_lcp (void)
{
    int i, cp;

    cp = 0;

    for (i = 0; i < N; i++) {
        int x = perm[i];
        if (perm[i] - 1 < 0) continue;
        int j = pos[x - 1];

        for (; s[i + cp] == s[j + cp]; cp++);

        lcp[x] = cp;
        if (cp > 0) cp--;
    }
    lcp[0] = 0;
}

int minlcp[maxn*8];

#define nleft(z) (2*(z))
#define nright(z) (2*(z) + 1)

void precalc_rmq (int nod, int left, int right)
{
    if (left == right)
       minlcp[nod] = lcp[left];
    else {
       int mid = (left + right) / 2;

       precalc_rmq (nleft(nod), left, mid);
       precalc_rmq (nright(nod), mid + 1, right);

       minlcp[nod] = minlcp[nleft(nod)] <? minlcp[nright(nod)];
    }
}

int rmq (int nod, int left, int right, int qleft, int qright)
{
    if (qleft <= left && qright >= right)
       return minlcp[nod];
    else {
       int mid = (left + right) / 2, sol;

       if (qleft <= mid) {
          sol = rmq (nleft(nod), left, mid, qleft, qright);
          if (qright > mid)
             sol <?= rmq (nright(nod), mid + 1, right, qleft, qright);
          
       } else {
          sol = rmq (nright(nod), mid + 1, right, qleft, qright);
       }

       return sol;
    }
}

int get_lcp (int lt, int rt)
{
    int left = perm[lt] <? perm[rt], right = perm[lt] >? perm[rt];

    return rmq (1, 0, N, left + 1, right);
}

void solve (void)
{
    int i, sol;

    build_string();
    sarray();
    compute_lcp();
    precalc_rmq (1, 0, N);

    for (i = 1; i <= ntree; i++) {
        sol = get_lcp(node_start[i], pattern_start);
        printf ("%d\n", countS[sol - 1]);
    }
}

int main(void)
{
    freopen ("arbfind.in", "rt", stdin);
    freopen ("arbfind.out", "wt", stdout);

//    printf ("-------------------------\n");

    init();
    solve();

    return 0;
}

